function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import { classNames } from '@shopify/css-utilities';
import { useResponsive } from '../../utilities/responsive';
import styles from './View.css';

/**
 * A View is a generic container component. Its contents will always be their
 * “natural” size, so this component can be useful in layout components (like `Layout`, `Tiles`,
 * `BlockStack`, `InlineStack`) that would otherwise stretch their children to fit.
 */
export function View(_ref) {
  var blockPadding = _ref.blockPadding,
      inlinePadding = _ref.inlinePadding,
      padding = _ref.padding,
      children = _ref.children,
      media = _ref.media,
      props = _objectWithoutProperties(_ref, ["blockPadding", "inlinePadding", "padding", "children", "media"]);

  // Support Argo blockPadding & inlinePadding props
  var useArgoPadding = !padding && (blockPadding || inlinePadding);
  var responsiveClassNames = useResponsive(_objectSpread(_objectSpread({}, props), {}, {
    padding: useArgoPadding ? convertPadding(blockPadding, inlinePadding) : padding
  }), media);
  return /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.View, responsiveClassNames && responsiveClassNames.map(function (className) {
      return styles[className];
    }))
  }, children);
} // TODO: remove when no longer supported in favor of padding

export function convertPadding(blockPadding, inlinePadding) {
  var padding = function padding(_padding) {
    switch (_padding) {
      case 'base':
        return 'base';

      case 'tight':
        return 'tight1x';

      case 'extraTight':
        return 'tight4x';

      case 'loose':
        return 'loose1x';

      case 'extraLoose':
        return 'loose4x';

      default:
        return 'none';
    }
  };

  return [padding(blockPadding), padding(inlinePadding)];
}