"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.View = View;
exports.convertPadding = convertPadding;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _responsive = require("../../utilities/responsive");

var _View = _interopRequireDefault(require("./View.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * A View is a generic container component. Its contents will always be their
 * “natural” size, so this component can be useful in layout components (like `Layout`, `Tiles`,
 * `BlockStack`, `InlineStack`) that would otherwise stretch their children to fit.
 */
function View({
  blockPadding,
  inlinePadding,
  padding,
  children,
  media,
  ...props
}) {
  // Support Argo blockPadding & inlinePadding props
  const useArgoPadding = !padding && (blockPadding || inlinePadding);
  const responsiveClassNames = (0, _responsive.useResponsive)({ ...props,
    padding: useArgoPadding ? convertPadding(blockPadding, inlinePadding) : padding
  }, media);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_View.default.View, responsiveClassNames && responsiveClassNames.map(className => _View.default[className]))
  }, children);
} // TODO: remove when no longer supported in favor of padding


function convertPadding(blockPadding, inlinePadding) {
  const padding = padding => {
    switch (padding) {
      case 'base':
        return 'base';

      case 'tight':
        return 'tight1x';

      case 'extraTight':
        return 'tight4x';

      case 'loose':
        return 'loose1x';

      case 'extraLoose':
        return 'loose4x';

      default:
        return 'none';
    }
  };

  return [padding(blockPadding), padding(inlinePadding)];
}