"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateResponsiveClassnames = generateResponsiveClassnames;
exports.convertLogicalProps = convertLogicalProps;
exports.useResponsive = useResponsive;

var _cssUtilities = require("@shopify/css-utilities");

const classNamesMap = {
  padding: ['paddingInlineStart', 'paddingInlineEnd', 'paddingBlockStart', 'paddingBlockEnd'],
  paddingInline: ['paddingInlineStart', 'paddingInlineEnd'],
  paddingInlineStart: 'paddingInlineStart',
  paddingInlineEnd: 'paddingInlineEnd',
  paddingBlock: ['paddingBlockStart', 'paddingBlockEnd'],
  paddingBlockStart: 'paddingBlockStart',
  paddingBlockEnd: 'paddingBlockEnd',
  background: 'background',
  border: ['borderInlineStart', 'borderInlineEnd', 'borderBlockStart', 'borderBlockEnd'],
  borderInline: ['borderInlineStart', 'borderInlineEnd'],
  borderInlineStart: 'borderInlineStart',
  borderInlineEnd: 'borderInlineEnd',
  borderBlock: ['borderBlockStart', 'borderBlockEnd'],
  borderBlockStart: 'borderBlockStart',
  borderBlockEnd: 'borderBlockEnd',
  borderWidth: ['borderWidthInlineStart', 'borderWidthInlineEnd', 'borderWidthBlockStart', 'borderWidthBlockEnd'],
  borderWidthInline: ['borderWidthInlineStart', 'borderWidthInlineEnd'],
  borderWidthInlineStart: 'borderWidthInlineStart',
  borderWidthInlineEnd: 'borderWidthInlineEnd',
  borderWidthBlock: ['borderWidthBlockStart', 'borderWidthBlockEnd'],
  borderWidthBlockStart: 'borderWidthBlockStart',
  borderWidthBlockEnd: 'borderWidthBlockEnd',
  borderColor: ['borderColorInlineStart', 'borderColorInlineEnd', 'borderColorBlockStart', 'borderColorBlockEnd'],
  borderRadius: ['borderRadiusInlineStart', 'borderRadiusInlineEnd', 'borderRadiusBlockStart', 'borderRadiusBlockEnd'],
  borderRadiusInline: ['borderRadiusInlineStart', 'borderRadiusInlineEnd'],
  borderRadiusInlineStart: 'borderRadiusInlineStart',
  borderRadiusInlineEnd: 'borderRadiusInlineEnd',
  borderRadiusBlock: ['borderRadiusBlockStart', 'borderRadiusBlockEnd'],
  borderRadiusBlockStart: 'borderRadiusBlockStart',
  borderRadiusBlockEnd: 'borderRadiusBlockEnd',
  spacing: 'spacing'
};

function generateResponsiveClassnames(props, viewportSize) {
  return Object.entries(props).filter(([prop, value]) => classNamesMap[prop] && value).reduce((classNames, [prop, value]) => {
    const property = classNamesMap[prop];

    if (Array.isArray(property)) {
      return [...classNames, ...property.map(property => viewportSize ? (0, _cssUtilities.variationName)((0, _cssUtilities.variationName)(viewportSize, property), value) : (0, _cssUtilities.variationName)(property, value))];
    }

    return [...classNames, viewportSize ? (0, _cssUtilities.variationName)((0, _cssUtilities.variationName)(viewportSize, property), value) : (0, _cssUtilities.variationName)(property, value)];
  }, []);
}

function convertLogicalProps(props) {
  return Object.assign({}, ...Object.entries(props).map(([prop, value]) => {
    if (Array.isArray(value)) {
      if (value.length === 2) {
        const [block, inline] = value;
        return {
          [`${prop}Block`]: block,
          [`${prop}Inline`]: inline
        };
      } else if (value.length === 4) {
        const [blockStart, inlineEnd, blockEnd, inlineStart] = value;
        return {
          [`${prop}BlockStart`]: blockStart,
          [`${prop}InlineEnd`]: inlineEnd,
          [`${prop}BlockEnd`]: blockEnd,
          [`${prop}InlineStart`]: inlineStart
        };
      }
    }

    return {
      [prop]: value
    };
  }));
}

function useResponsive(props, media) {
  return [...generateResponsiveClassnames(convertLogicalProps(props)), ...(media ? media.map(({
    viewportSize,
    ...props
  }) => generateResponsiveClassnames(convertLogicalProps(props), viewportSize)).reduce((classNames, className) => classNames.concat(className), []) : [])];
}