"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useResponsive = exports.convertLogicalProps = exports.generateResponsiveClassnames = void 0;
const css_utilities_1 = require("@shopify/css-utilities");
const classNamesMap = {
    padding: [
        'paddingInlineStart',
        'paddingInlineEnd',
        'paddingBlockStart',
        'paddingBlockEnd',
    ],
    paddingInline: ['paddingInlineStart', 'paddingInlineEnd'],
    paddingInlineStart: 'paddingInlineStart',
    paddingInlineEnd: 'paddingInlineEnd',
    paddingBlock: ['paddingBlockStart', 'paddingBlockEnd'],
    paddingBlockStart: 'paddingBlockStart',
    paddingBlockEnd: 'paddingBlockEnd',
    background: 'background',
    border: [
        'borderInlineStart',
        'borderInlineEnd',
        'borderBlockStart',
        'borderBlockEnd',
    ],
    borderInline: ['borderInlineStart', 'borderInlineEnd'],
    borderInlineStart: 'borderInlineStart',
    borderInlineEnd: 'borderInlineEnd',
    borderBlock: ['borderBlockStart', 'borderBlockEnd'],
    borderBlockStart: 'borderBlockStart',
    borderBlockEnd: 'borderBlockEnd',
    borderWidth: [
        'borderWidthInlineStart',
        'borderWidthInlineEnd',
        'borderWidthBlockStart',
        'borderWidthBlockEnd',
    ],
    borderWidthInline: ['borderWidthInlineStart', 'borderWidthInlineEnd'],
    borderWidthInlineStart: 'borderWidthInlineStart',
    borderWidthInlineEnd: 'borderWidthInlineEnd',
    borderWidthBlock: ['borderWidthBlockStart', 'borderWidthBlockEnd'],
    borderWidthBlockStart: 'borderWidthBlockStart',
    borderWidthBlockEnd: 'borderWidthBlockEnd',
    borderColor: [
        'borderColorInlineStart',
        'borderColorInlineEnd',
        'borderColorBlockStart',
        'borderColorBlockEnd',
    ],
    borderRadius: [
        'borderRadiusInlineStart',
        'borderRadiusInlineEnd',
        'borderRadiusBlockStart',
        'borderRadiusBlockEnd',
    ],
    borderRadiusInline: ['borderRadiusInlineStart', 'borderRadiusInlineEnd'],
    borderRadiusInlineStart: 'borderRadiusInlineStart',
    borderRadiusInlineEnd: 'borderRadiusInlineEnd',
    borderRadiusBlock: ['borderRadiusBlockStart', 'borderRadiusBlockEnd'],
    borderRadiusBlockStart: 'borderRadiusBlockStart',
    borderRadiusBlockEnd: 'borderRadiusBlockEnd',
    spacing: 'spacing',
};
function generateResponsiveClassnames(props, viewportSize) {
    return Object.entries(props)
        .filter(([prop, value]) => classNamesMap[prop] && value)
        .reduce((classNames, [prop, value]) => {
        const property = classNamesMap[prop];
        if (Array.isArray(property)) {
            return [
                ...classNames,
                ...property.map((property) => viewportSize
                    ? css_utilities_1.variationName(css_utilities_1.variationName(viewportSize, property), value)
                    : css_utilities_1.variationName(property, value)),
            ];
        }
        return [
            ...classNames,
            viewportSize
                ? css_utilities_1.variationName(css_utilities_1.variationName(viewportSize, property), value)
                : css_utilities_1.variationName(property, value),
        ];
    }, []);
}
exports.generateResponsiveClassnames = generateResponsiveClassnames;
function convertLogicalProps(props) {
    return Object.assign({}, ...Object.entries(props).map(([prop, value]) => {
        if (Array.isArray(value)) {
            if (value.length === 2) {
                const [block, inline] = value;
                return {
                    [`${prop}Block`]: block,
                    [`${prop}Inline`]: inline,
                };
            }
            else if (value.length === 4) {
                const [blockStart, inlineEnd, blockEnd, inlineStart] = value;
                return {
                    [`${prop}BlockStart`]: blockStart,
                    [`${prop}InlineEnd`]: inlineEnd,
                    [`${prop}BlockEnd`]: blockEnd,
                    [`${prop}InlineStart`]: inlineStart,
                };
            }
        }
        return { [prop]: value };
    }));
}
exports.convertLogicalProps = convertLogicalProps;
function useResponsive(props, media) {
    return [
        ...generateResponsiveClassnames(convertLogicalProps(props)),
        ...(media
            ? media
                .map((_a) => {
                var { viewportSize } = _a, props = __rest(_a, ["viewportSize"]);
                return generateResponsiveClassnames(convertLogicalProps(props), viewportSize);
            })
                .reduce((classNames, className) => classNames.concat(className), [])
            : []),
    ];
}
exports.useResponsive = useResponsive;
